;; Generated package description from svg-lib.el  -*- no-byte-compile: t -*-
(define-package "svg-lib" "0.2.8.0.20231122.73323" "SVG tags, progress bars & icons" '((emacs "27.1")) :commit "710803c3bea1a25d6d47475c6e1eee734e7144ae" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("svg" "icons" "tags" "convenience") :url "https://github.com/rougier/svg-lib")
